<?php
/**
 * Page-Data-Scripting - module page_data_scripting_view
 *
 * Creates the menu for the user to add plugins or
 * script-calls on a page.
 *
 * @author Holger Irmler
 * @link http://www.HolgerIrmler.de/playground
 * @version 2.0
 * @date: 2010-04-02
 * @package hi_pd_scripting
 */
 
/**
 * hi_pd_scripting_view()
 * 
 * @param array $page Gets cleaned of unallowed doublequotes, that will destroy input-fields
 * @return string $view Returns the created view
 * @global string $sn Scriptname (base-directory)
 * @global string $su Selected-URL (query-string)
 * @global array $plugin_tx Plugin-texts
 * @global array $plugin_cf Plugin-configuration
 * @global array $tx CMSimple-texts
 * @global array $pth CMSimple-paths
 * @global array $cf CMSimple-config-settings
 */
 
//Check if PLUGINLOADER is calling and DIE if not
if(!defined('PLUGINLOADER_VERSION')){die('Plugin '. basename(dirname(__FILE__)) . ' requires a newer version of the Pluginloader. No direct access.');} 

function hi_pd_scripting_view($page){
	global $sn, $su, $plugin_tx, $plugin_cf, $tx, $pth, $cf;
	
	//check the maximum allowed value of fields
	if (!isset($plugin_cf['hi_pd_scripting']['scripts_max_on_page']) || $plugin_cf['hi_pd_scripting']['scripts_max_on_page'] > HI_PD_SCRIPTING_MAX) {
		$plugin_cf['hi_pd_scripting']['scripts_max_on_page'] = HI_PD_SCRIPTING_MAX;
	}
	if ($plugin_cf['hi_pd_scripting']['mode_advanced'] !== '1'){
		$plugin_cf['hi_pd_scripting']['scripts_max_on_page'] = 1;
	}
	
	$strChecked = ' checked';
	$strDisabled = ' disabled';
	//$strSelected = ' selected';
	if ($cf['xhtml']['endtags'] == 'true'){
		$strChecked .= '="checked"';
		$strDisabled .= '="disabled"';
		//$strSelected .= '="selected"';
	}
	
	$lang = $plugin_tx['hi_pd_scripting'];
	$help_icon = tag('img src = "'.$pth['folder']['plugins']. 'pluginloader/css/help_icon.png"');

	$view ="\n".'<form action="'.$sn.'?'.$su.'" method="post" id = "hi_pd_scripting" name = "hi_pd_scripting">';	
	$view .= "\n\t".'<p><b>'.$lang['form_title'].'</b></p>';

	################################################ 
	
	for ($i = 1; $i <= $plugin_cf['hi_pd_scripting']['scripts_max_on_page']; $i++) {
		$view .= "\n\t".'<a class="pl_tooltip" href="#">'.$help_icon.'<span>'.$lang['hint_activate'].'</span></a>';
		$view .= "\n\t".'<span class = "hi_pd_scripting_label">'.$lang['activate'].'</span>'.tag('br');
		$checked = '';
		if($page['hi_pd_scripting_active'.$i] == '1'){
		$checked = $strChecked;
		}
		$js = " onclick=\"window.document.hi_pd_scripting.hi_pd_scripting_code$i.disabled = false;\"";

		$view .= "\n\t\t".tag('input type="radio" name="hi_pd_scripting_active'.$i.'" value="1" id = "scripting_active'.$i.'_yes"'.$js. $checked). '<label for="scripting_active'.$i.'_yes">'.$lang['yes'].'</label>';
		$checked = '';
		$disabled = '';
		if($page['hi_pd_scripting_active'.$i] !== '1'){
			$checked = $strChecked;
			$disabled = $strDisabled;
		}
		$js = " onclick=\"window.document.hi_pd_scripting.hi_pd_scripting_code$i.disabled = true;\"";
		$view .= "\n\t\t".tag('input type="radio" name="hi_pd_scripting_active'.$i.'" value="0" id = "scripting_active'.$i.'_no"'.$checked .$js). '<label for="scripting_active'.$i.'_no">'.$lang['no'].'</label>' .tag('br');
	
		$view .= "\n\t".'<a class="pl_tooltip" href="#">'.$help_icon.'<span>'.$lang['hint_code'].'</span></a>';
		$view .= "\n\t".'<span class = "hi_pd_scripting_label">'.$lang['code'].'</span>'.tag('br');
		$view .= "\n\t\t".tag('input type="text" size = "50" name="hi_pd_scripting_code'.$i.'" id = "code'.$i.'" value="'. str_replace('"', '&quot;', $page['hi_pd_scripting_code'.$i]).'"'.$disabled).tag('br');
		
		//create placeholder-fields only in advanced-mode
		if ($plugin_cf['hi_pd_scripting']['mode_advanced'] == '1'){
			$view .= "\n\t".'<a class="pl_tooltip" href="#">'.$help_icon.'<span>'.$lang['hint_placeholder'].'</span></a>';
			$view .= "\n\t".'<span class = "hi_pd_scripting_label">'.$lang['placeholder'].'</span>'.tag('br');
			$view .= "\n\t\t".tag('input type="text" size = "50" name="hi_pd_scripting_placeholder'.$i.'" id = "placeholder'.$i.'" value="'. str_replace('"', '&quot;', $page['hi_pd_scripting_placeholder'.$i]).'"').tag('br');
		}	
	
		// no <hr> after the last entry
		if ($i < $plugin_cf['hi_pd_scripting']['scripts_max_on_page']) $view .= "\n\t".tag('hr');
	}

	################################################
	$view .= "\n\t".tag('br');
	$view .= "\n\t"."<small>pd_scripting plugin &copy;2010 <a href=\"http://www.holgerirmler.de/playground\" target=\"_blank\">Holger Irmler</a></small>";
	$view .= "\n\t".tag('input name = "save_page_data" type = "hidden"');
	$view .= "\n\t".'<div style="text-align: right">';
	$view .= "\n\t\t".tag('input type="submit" value="'.$lang['submit'].'"').tag('br');
	$view .= "\n\t".'</div>';
	$view .= "\n".'</form>';
	return $view;
}
?>